"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Config_1 = require("./model/Config");
const NResponse_1 = require("./model/NResponse");
class nfetch {
    constructor(configs = new Config_1.NConfig()) {
        this.get = (url, configs) => this.onRequest("GET", url, null, configs);
        this.post = (url, body, configs) => this.onRequest("POST", url, body, configs);
        this.put = (url, body, configs) => this.onRequest("PUT", url, body, configs);
        this.patch = (url, body, configs) => this.onRequest("PATCH", url, body, configs);
        this.head = (url, configs) => this.onRequest("HEAD", url, null, configs);
        this.options = (url, body, configs) => this.onRequest("OPTIONS", url, body, configs);
        this.delete = (url, body, configs) => this.onRequest("DELETE", url, body, configs);
        this.configs = Object.assign(new Config_1.NConfig(), configs);
    }
    fromForm(url, formData) {
        return {
            post: this.post(url, { body: formData }),
            put: this.put(url, { body: formData }),
            patch: this.patch(url, { body: formData }),
            options: this.options(url, { body: formData }),
            delete: this.delete(url, { body: formData })
        };
    }
    async all(requests) {
        let data = [];
        for (let req of requests) {
            data.push(await req);
        }
        return data;
    }
    resolveOptions(method, data, configs) {
        const body = data ? JSON.stringify(data) : null;
        return Object.assign(this.configs, { ...configs, method, body });
    }
    async onRequest(method, url, body, configs = this.configs) {
        const urlRequest = this.configs.prefixUrl + url;
        const options = this.resolveOptions(method, body, configs);
        const request = fetch(urlRequest, options);
        setTimeout(() => {
            this.resolveTimeout(options);
        }, this.configs.timeout);
        const res = await request;
        return new NResponse_1.default(res, await res.json());
    }
    async resolveTimeout(resInit) {
        const status = 408;
        const statusText = "Timeout";
        const _resInit = Object.assign(resInit, { status, statusText });
        const res = new Response(undefined, _resInit);
        throw new NResponse_1.default(res);
    }
    async retry(request, limit) {
        try {
            return await request;
        }
        catch (error) {
            if (limit === 1)
                throw error;
            return await this.retry(request, limit - 1);
        }
    }
}
exports.nfetch = nfetch;
exports.default = new nfetch();
